Imports System.Text
Imports System.Text.RegularExpressions
Imports VaultClientOperationsLib
Imports VaultClientNetLib.ClientService

'  Component Information
'
'  Class Name:      VaultAPI.vb
'  Author:          Darren Sargent/John E. Miller
'  Date:            05/13/2004
'  Description:     This component is part of a custom Vault Search tool built on the 
'                   Vault Client API.  The application simply searches on a specified repository/folder and
'                   returns a text list of all files which match the search terms.
'  Copyright:       2004, John E. Miller/Herbalife International of America, Inc.
'  Disclaimer:      This software/sourcecode is supplied as-is with no warranty, express or implied.
'                   Feel free to modify/redistribute this software/sourcecode at your own peril.  The author and 
'                   Herbalife International of America accept no responsibility for damages (monetary or otherwise) 
'                   incurred as a result of the use of this software.
'  Contact:         johnmi@herbalife.com

Public Class VaultAPI

    Public Shared Function Authenticate(ByVal vaultClient As ClientInstance, _
                                        ByVal userName As String, _
                                        ByVal passWord As String, _
                                        ByVal hostName As String) As Boolean

        Try
            vaultClient.Login(hostName, userName, passWord)
            ' Login successful
            Return True
        Catch ex As System.Web.Services.Protocols.SoapException
            '  Login Failed
            Return False
        Catch ex As System.Exception
            '  Login Failed
            Return False
        End Try

    End Function

    Public Shared Sub SearchForFileName(ByVal vaultFolder As VaultClientFolder, _
                                            ByVal fileName As String, _
                                            ByRef returnArray As ArrayList, _
                                            ByVal exactMatch As Boolean, _
                                            ByVal caseSensitive As Boolean)

        If Not (vaultFolder.Files Is Nothing) Then
            For Each subfile As VaultClientFile In vaultFolder.Files
                If exactMatch Then
                    If (caseSensitive = False And subfile.Name.ToUpper = fileName.ToUpper) Then
                        returnArray.Add(subfile)
                    ElseIf (subfile.Name = fileName) Then
                        returnArray.Add(subfile)
                    End If
                Else
                    If (caseSensitive = False And Regex.IsMatch(subfile.Name, fileName, RegexOptions.IgnoreCase)) Then
                        returnArray.Add(subfile)
                    ElseIf (Regex.IsMatch(subfile.Name, fileName)) Then
                        returnArray.Add(subfile)
                    End If
                End If
            Next
        End If

        If Not (vaultFolder.Folders Is Nothing) Then
            For Each subfolder As VaultClientFolder In vaultFolder.Folders
                SearchForFileName(subfolder, fileName, returnArray, exactMatch, caseSensitive)
            Next
        End If

    End Sub

    Public Shared Function SetActiveRepository(ByVal client As ClientInstance, _
                                        ByVal RepID As String, _
                                        ByVal RepUniqueID As String) As Boolean

        Try
            client.SetActiveRepositoryID(RepID, client.Connection.Username, RepUniqueID, True, True)
            If client.ActiveRepositoryID > 0 Then
                Return True
            Else
                Return False
            End If
        Catch ex As System.Exception
            Return False
        End Try

    End Function

    Public Shared Function ListRepositories(ByVal client As ClientInstance) As VaultRepositoryInfo()

        Dim l_arrReps() As VaultRepositoryInfo = Nothing

        'List all the repositories on the server.
        client.ListRepositories(l_arrReps)

        Return l_arrReps

    End Function

End Class
