Imports VaultClientOperationsLib
Imports System.Text
Imports System.IO

'  Component Information
'
'  Class Name:      VaultResults.vb
'  Author:          John E. Miller
'  Date:            05/13/2004
'  Description:     This component is part of a custom Vault Search tool built on the 
'                   Vault Client API.  The application simply searches on a specified repository/folder and
'                   returns a text list of all files which match the search terms.
'  Copyright:       2004, John E. Miller/Herbalife International of America, Inc.
'  Disclaimer:      This software/sourcecode is supplied as-is with no warranty, express or implied.
'                   Feel free to modify/redistribute this software/sourcecode at your own peril.  The author and 
'                   Herbalife International of America accept no responsibility for damages (monetary or otherwise) 
'                   incurred as a result of the use of this software.
'  Contact:         johnmi@herbalife.com
'
Public Class VaultResults

    Inherits System.Windows.Forms.Form

    Private m_PrintStream As StringReader
    Private m_strSearchFrag As String

#Region " Windows Form Designer generated code "

    Public Sub New()
        MyBase.New()

        'This call is required by the Windows Form Designer.
        InitializeComponent()

        'Add any initialization after the InitializeComponent() call

    End Sub

    'Form overrides dispose to clean up the component list.
    Protected Overloads Overrides Sub Dispose(ByVal disposing As Boolean)
        If disposing Then
            If Not (components Is Nothing) Then
                components.Dispose()
            End If
        End If
        MyBase.Dispose(disposing)
    End Sub

    'Required by the Windows Form Designer
    Private components As System.ComponentModel.IContainer

    'NOTE: The following procedure is required by the Windows Form Designer
    'It can be modified using the Windows Form Designer.  
    'Do not modify it using the code editor.
    Friend WithEvents txtResults As System.Windows.Forms.TextBox
    Friend WithEvents btnClose As System.Windows.Forms.Button
    Friend WithEvents btnPrint As System.Windows.Forms.Button
    Friend WithEvents btnSave As System.Windows.Forms.Button
    <System.Diagnostics.DebuggerStepThrough()> Private Sub InitializeComponent()
        Dim resources As System.Resources.ResourceManager = New System.Resources.ResourceManager(GetType(VaultResults))
        Me.txtResults = New System.Windows.Forms.TextBox
        Me.btnClose = New System.Windows.Forms.Button
        Me.btnPrint = New System.Windows.Forms.Button
        Me.btnSave = New System.Windows.Forms.Button
        Me.SuspendLayout()
        '
        'txtResults
        '
        Me.txtResults.Font = New System.Drawing.Font("Arial", 8.0!, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, CType(0, Byte))
        Me.txtResults.Location = New System.Drawing.Point(5, 5)
        Me.txtResults.Multiline = True
        Me.txtResults.Name = "txtResults"
        Me.txtResults.ScrollBars = System.Windows.Forms.ScrollBars.Both
        Me.txtResults.Size = New System.Drawing.Size(730, 395)
        Me.txtResults.TabIndex = 0
        Me.txtResults.TabStop = False
        Me.txtResults.Text = ""
        Me.txtResults.WordWrap = False
        '
        'btnClose
        '
        Me.btnClose.DialogResult = System.Windows.Forms.DialogResult.Cancel
        Me.btnClose.Location = New System.Drawing.Point(660, 460)
        Me.btnClose.Name = "btnClose"
        Me.btnClose.TabIndex = 3
        Me.btnClose.Text = "&Close"
        '
        'btnPrint
        '
        Me.btnPrint.Location = New System.Drawing.Point(660, 410)
        Me.btnPrint.Name = "btnPrint"
        Me.btnPrint.TabIndex = 1
        Me.btnPrint.Text = "&Print"
        '
        'btnSave
        '
        Me.btnSave.Location = New System.Drawing.Point(660, 435)
        Me.btnSave.Name = "btnSave"
        Me.btnSave.TabIndex = 2
        Me.btnSave.Text = "&Save"
        '
        'VaultResults
        '
        Me.AutoScaleBaseSize = New System.Drawing.Size(5, 13)
        Me.CancelButton = Me.btnClose
        Me.ClientSize = New System.Drawing.Size(739, 490)
        Me.Controls.Add(Me.btnSave)
        Me.Controls.Add(Me.btnPrint)
        Me.Controls.Add(Me.btnClose)
        Me.Controls.Add(Me.txtResults)
        Me.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedSingle
        Me.Icon = CType(resources.GetObject("$this.Icon"), System.Drawing.Icon)
        Me.MaximizeBox = False
        Me.Name = "VaultResults"
        Me.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen
        Me.Text = "Vault Search Results"
        Me.ResumeLayout(False)

    End Sub

#End Region

    Public WriteOnly Property SearchResults() As ArrayList

        Set(ByVal Value As ArrayList)

            Try
                Dim l_StrBuild As New StringBuilder
                l_StrBuild.Append(String.Concat("Search results for file name/fragment:  ", m_strSearchFrag, ControlChars.CrLf, ControlChars.NewLine))
                For Each l_Item As VaultClientFile In Value
                    l_StrBuild.Append(String.Concat(l_Item.FullPath, ControlChars.CrLf))
                Next
                txtResults.Text = l_StrBuild.ToString
                btnPrint.Focus()
            Catch ex As System.Exception
                MsgBox(String.Concat("Error:  ", ex.Source, ControlChars.CrLf, ex.Message, ControlChars.CrLf, ex.StackTrace, ControlChars.CrLf), MsgBoxStyle.OKOnly + MsgBoxStyle.Critical, "Error")
            End Try
        End Set

    End Property

    Public WriteOnly Property SearchFragment() As String

        Set(ByVal Value As String)
            m_strSearchFrag = Value
        End Set

    End Property

    Private Sub btnClose_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnClose.Click
        Me.Hide()
    End Sub

    Private Sub btnPrint_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnPrint.Click
        Try
            Dim l_StrBuild As New StringBuilder
            l_StrBuild.Append(txtResults.Text)
            m_PrintStream = New StringReader(l_StrBuild.ToString)

            Dim l_PrintDoc As New System.Drawing.Printing.PrintDocument
            AddHandler l_PrintDoc.PrintPage, AddressOf DocPrint_PrintPage
            l_PrintDoc.Print()

        Catch ex As System.Exception
            MsgBox(String.Concat("Error:  ", ex.Source, ControlChars.CrLf, ex.Message, ControlChars.CrLf, ex.StackTrace, ControlChars.CrLf), MsgBoxStyle.OKOnly + MsgBoxStyle.Critical, "Error")
        End Try

    End Sub

    Private Sub DocPrint_PrintPage(ByVal sender As Object, ByVal ev As System.Drawing.Printing.PrintPageEventArgs)

        Try
            Dim l_Font As Font = New Font("Arial", 8, FontStyle.Regular, GraphicsUnit.Point)
            Dim linesPerPage As Single = 0
            Dim yPos As Single = 0
            Dim count As Integer = 0
            Dim leftMargin As Single = ev.MarginBounds.Left - 100
            Dim topMargin As Single = ev.MarginBounds.Top
            Dim line As String = Nothing

            ' Calculate the number of lines per page.
            linesPerPage = ev.MarginBounds.Height / l_Font.GetHeight(ev.Graphics)

            ' Iterate over the file, printing each line.
            While count < linesPerPage
                line = m_PrintStream.ReadLine

                If line Is Nothing Then
                    Exit While
                End If

                yPos = topMargin + count * l_Font.GetHeight(ev.Graphics)
                ev.Graphics.DrawString(line, l_Font, Brushes.Black, leftMargin, _
                    yPos, New StringFormat)
                count += 1
            End While

            ' If more lines exist, print another page.
            If Not (line Is Nothing) Then
                ev.HasMorePages = True
            Else
                ev.HasMorePages = False
            End If
        Catch ex As System.Exception
            MsgBox(String.Concat("Error:  ", ex.Source, ControlChars.CrLf, ex.Message, ControlChars.CrLf, ex.StackTrace, ControlChars.CrLf), MsgBoxStyle.OKOnly + MsgBoxStyle.Critical, "Error")
        End Try

    End Sub

    Private Sub btnSave_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnSave.Click

        Try
            Dim l_FileDialog As New SaveFileDialog
            l_FileDialog.Title = "Save Vault Search Results Window...."
            l_FileDialog.InitialDirectory = AppDomain.CurrentDomain.BaseDirectory.ToString
            l_FileDialog.OverwritePrompt = True
            l_FileDialog.DefaultExt = ".txt"
            l_FileDialog.FileName = String.Concat(m_strSearchFrag, "_VaultSearch", Now.Ticks, ".txt")

            Dim l_Result As System.Windows.Forms.DialogResult = l_FileDialog.ShowDialog()

            If l_Result = DialogResult.OK Then
                Dim l_File As New FileStream(l_FileDialog.FileName, FileMode.Create)
                Dim l_bytResults() As Byte = Encoding.UTF8.GetBytes(txtResults.Text)
                l_File.Write(l_bytResults, 0, l_bytResults.Length)
                l_File.Close()
            End If
        Catch ex As System.Exception
            MsgBox(String.Concat("Error:  ", ex.Source, ControlChars.CrLf, ex.Message, ControlChars.CrLf, ex.StackTrace, ControlChars.CrLf), MsgBoxStyle.OKOnly + MsgBoxStyle.Critical, "Error")
        End Try

    End Sub

End Class
